package com.sun.corba.se.impl.util;

import java.net.MalformedURLException;
import java.rmi.server.RMIClassLoader;
import java.security.AccessController;
import com.sun.corba.se.impl.orbutil.GetPropertyAction;

public class JDKBridge
{
    private static final String LOCAL_CODEBASE_KEY = "java.rmi.server.codebase";
    private static final String USE_CODEBASE_ONLY_KEY = "java.rmi.server.useCodebaseOnly";
    private static String localCodebase;
    private static boolean useCodebaseOnly;
    
    public JDKBridge() {
    }
    
    public static String getLocalCodebase() {
        return JDKBridge.localCodebase;
    }
    
    public static boolean useCodebaseOnly() {
        return JDKBridge.useCodebaseOnly;
    }
    
    public static Class loadClass(String name, String s, ClassLoader classLoader) throws ClassNotFoundException {
        if (classLoader == null) {
            return loadClassM(name, s, JDKBridge.useCodebaseOnly);
        }
        try {
            return loadClassM(name, s, JDKBridge.useCodebaseOnly);
        }
        catch (ClassNotFoundException ex) {
            return classLoader.loadClass(name);
        }
    }
    
    public static Class loadClass(String s, String s2) throws ClassNotFoundException {
        return loadClass(s, s2, null);
    }
    
    public static Class loadClass(String s) throws ClassNotFoundException {
        return loadClass(s, null, null);
    }
    
    public static final void main(String[] array) {
        System.out.println("1.2 VM");
    }
    
    public static synchronized void setCodebaseProperties() {
        String localCodebase = (String)AccessController.doPrivileged(new GetPropertyAction("java.rmi.server.codebase"));
        if (localCodebase != null && localCodebase.trim().length() > 0) {
            JDKBridge.localCodebase = localCodebase;
        }
        String s = (String)AccessController.doPrivileged(new GetPropertyAction("java.rmi.server.useCodebaseOnly"));
        if (s != null && s.trim().length() > 0) {
            JDKBridge.useCodebaseOnly = (boolean)Boolean.valueOf(s);
        }
    }
    
    public static synchronized void setLocalCodebase(String localCodebase) {
        JDKBridge.localCodebase = localCodebase;
    }
    
    private static Class loadClassM(String string, String codebase, boolean b) throws ClassNotFoundException {
        try {
            return JDKClassLoader.loadClass(null, string);
        }
        catch (ClassNotFoundException ex) {
            try {
                if (!b && codebase != null) {
                    return RMIClassLoader.loadClass(codebase, string);
                }
                return RMIClassLoader.loadClass(string);
            }
            catch (MalformedURLException ex2) {
                string = string + ": " + ex2.toString();
                throw new ClassNotFoundException(string);
            }
        }
    }
    
    static {
        JDKBridge.localCodebase = null;
        setCodebaseProperties();
    }
}
